#
# spec file for package python-aiohttp-socks
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-aiohttp-socks
Version:        0.9.0
Release:        1.1
Summary:        SOCKS proxy connector for aiohttp
License:        Apache-2.0
URL:            https://github.com/romis2012/aiohttp-socks
Source:         https://files.pythonhosted.org/packages/source/a/aiohttp_socks/aiohttp_socks-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  dos2unix
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-aiohttp >= 2.3.2
Requires:       python-attrs >= 19.2.0
Requires:       python-python-socks >= 2.0.0
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module aiohttp >= 2.3.2}
BuildRequires:  %{python_module async_timeout}
BuildRequires:  %{python_module attrs >= 1.0.1}
BuildRequires:  %{python_module python-socks >= 2.0.0}
# /SECTION
%python_subpackages

%description
SOCKS proxy connector for aiohttp

%prep
%autosetup -p1 -n aiohttp_socks-%{version}
dos2unix README.md

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# tests need access to the internet
#%%pytest

# so try at least a simple import
%python_exec -c 'from aiohttp_socks import ProxyConnector'

%files %{python_files}
%doc README.md
%license LICENSE.txt
%{python_sitelib}/aiohttp_socks
%{python_sitelib}/aiohttp_socks-%{version}*-info

%changelog
* Wed Aug 21 2024 Frantisek Simorda <frantisek.simorda@suse.com>
- Update to 0.9.0:
  * Fix compatibility with aiohttp v3.10
  * Update requirements-dev.txt
* Fri Dec 29 2023 ecsos <ecsos@opensuse.org>
- Add missing buildrequire to fix Leap build error.
* Fri Nov 10 2023 Dirk Müller <dmueller@suse.com>
- update to 0.8.4:
  * Reimplement proxy chains
  * Implement another solution to fix issue #27
* Mon Sep 18 2023 Jiri Slaby <jslaby@suse.cz>
- update to 0.8.3:
  * fixes for https://github.com/romis2012/aiohttp-socks/issues/27
* Wed Jul  5 2023 Matej Cepl <mcepl@suse.com>
- Clean up SPEC file.
* Tue Jul  4 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Thu Feb 23 2023 Dirk Müller <dmueller@suse.com>
- update to 0.8.0:
  * Added `proxy_ssl` parameter
* Sat Jan 15 2022 Dirk Müller <dmueller@suse.com>
- update to 0.7.1:
  Pin python-socks dependency to the >=2.0.0
  Upgrade python-socks to 2.0.0
* Wed Apr 21 2021 Jiri Slaby <jslaby@suse.cz>
- Update to 0.6.0:
  * Use a custom proxy server and local http server for tests
  * Use python-socks extended API
- Add a simple import test at least
* Tue Feb 23 2021 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.5.5:
  * Fix asyncio DeprecationWarning: The loop argument is deprecated
  * Make deprecated API (SocksConnector etc) available again
  * Misc fixes, remove deprecated API (SocksConnector etc)
  * Fix cancellation handling
  * Improve timeouts handling
  * First use ipv4 when resolving hostnames
  * Change the default value of the family parameter to AF_UNSPEC
  * Make it compatible with aiohttp 2.x again
* Thu Jan 16 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 0.3.4
  * Resolve proxy host explicitly
  * Add Proxy chaining support
  * Fix StreamSocketReadWriteMixin.read_all
  * Add HTTP proxy support
* Mon Feb 25 2019 Tomáš Chvátal <tchvatal@suse.com>
- Use pypi archive instead of github one, no difference for us
* Tue Feb 12 2019 Tomáš Chvátal <tchvatal@suse.com>
- Disable the tests as they do not work without direct network
  access
* Mon Feb 11 2019 Jiri Slaby <jslaby@suse.com>
- clean up spec file
* Wed Feb  6 2019 Jiri Slaby <jslaby@suse.com>
- initial package
